import logging
import os

from jnpr.junos import Device
from lxml import etree

from inventory_provider import config

SCHEMA_FILENAME = os.path.realpath(os.path.join(
    os.path.dirname(__file__),
    "data",
    "juniper-netconf.xsd"
))


def _load_netconf(hostname, ssh_params):
    dev = Device(
        host=hostname,
        user=ssh_params['username'],
        ssh_private_key_file=ssh_params['private-key'])
    dev.open()
    print(dev.facts)
    return dev.rpc.get_config()


def _routers():
    filename = os.path.realpath(os.path.join(
        os.path.dirname(__file__),
        'netdash-alldevices.txt'))

    with open(filename) as f:
        for hostname in f.readlines():
            hostname = hostname.strip()
            if hostname in {
                    'mx1.kau.lt.geant.net',
                    'mx1.tal.ee.geant.net',
                    'mx2.kau.lt.geant.net',
                    'mx2.rig.lv.geant.net',
                    'mx2.tal.ee.geant.net',
                    'srx1.am.office.geant.net',
                    'srx2.am.office.geant.net',
                    'srx1.ch.office.geant.net',
                    'srx2.ch.office.geant.net'}:
                continue
            yield hostname


if __name__ == "__main__":

    logging.basicConfig(level=logging.INFO)

    TEST_DATA_DIR = os.path.dirname(__file__)
    CONFIG_FILENAME = "config.json"
    SCHEMA_FILENAME = os.path.join(TEST_DATA_DIR, "juniper-netconf.xsd")

    with open(CONFIG_FILENAME) as f:
        params = config.load(f)
    for r in _routers():
        logging.info("router: " + r)
        netconf = _load_netconf(r, params['ssh'])
        filename = os.path.join(
            TEST_DATA_DIR,
            "%s-netconf.xml" % r)
        with open(filename, 'w') as f:
            f.write(etree.tostring(netconf, encoding='unicode'))
